@@ -39,7 +39,14 @@ static inline int is_update_needed(void);
 
 static int is_active(GtkWidget *widget)
 {
-	return GTK_TOGGLE_BUTTON(widget)->active ? 1 : 0;
+	return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)) ? 1 : 0;
+}
+
+static void label_set(GtkWidget* widget, const char* str)
+{
+	const char* old = gtk_label_get_text(GTK_LABEL(widget));
+	if (strcmp(old, str))
+		gtk_label_set_text(GTK_LABEL(widget), str);
 }
 
 void master_clock_update(void)
@@ -170,8 +177,8 @@ gint master_clock_status_timeout_callback(gpointer data)
 	snd_ctl_elem_value_set_name(sw, "Word Clock Status");
 	if ((err = snd_ctl_elem_read(ctl, sw)) < 0)
 		g_print("Unable to determine word clock status: %s\n", snd_strerror(err));
-	gtk_label_set_text(GTK_LABEL(hw_master_clock_status_label),
-			   snd_ctl_elem_value_get_boolean(sw, 0) ? "No signal" : "Locked");
+	label_set(hw_master_clock_status_label,
+		  snd_ctl_elem_value_get_boolean(sw, 0) ? "No signal" : "Locked");
 	return TRUE;
 }
 
@@ -246,7 +253,7 @@ gint internal_clock_status_timeout_callback(gpointer data)
 			}
 		}
 	}
-	gtk_label_set_text(GTK_LABEL(hw_master_clock_actual_rate_label), label);
+	label_set(hw_master_clock_actual_rate_label, label);
 	return TRUE;
 }
 
@@ -354,7 +361,7 @@ void volume_change_rate_adj(GtkAdjustment *adj, gpointer data)
 {
 	int err;
 	
-	snd_ctl_elem_value_set_integer(volume_rate, 0, adj->value);
+	snd_ctl_elem_value_set_integer(volume_rate, 0, gtk_adjustment_get_value(adj));
 	if ((err = snd_ctl_elem_write(ctl, volume_rate)) < 0)
 		g_print("Unable to write volume change rate: %s\n", snd_strerror(err));
 }
@@ -455,9 +462,9 @@ void profi_stream_toggled(GtkWidget *togglebutton, gpointer data)
 		return;
 	iec958.status[1] &= ~IEC958_AES1_PRO_MODE;
 	if (!strcmp(str, "NOTID")) {
-		iec958.status[0] |= IEC958_AES1_PRO_MODE_STEREOPHONIC;
+		iec958.status[1] |= IEC958_AES1_PRO_MODE_NOTID;
 	} else if (!strcmp(str, "Stereo")) {
-		iec958.status[0] |= IEC958_AES1_PRO_MODE_NOTID;
+		iec958.status[1] |= IEC958_AES1_PRO_MODE_STEREOPHONIC;
 	}
 	snd_ctl_elem_value_set_iec958(spdif_output, &iec958);
 	spdif_output_write();
@@ -500,7 +507,7 @@ void consumer_copyright_toggled(GtkWidget *togglebutton, gpointer data)
 	if (!strcmp(str, "Copyright")) {
 		iec958.status[0] &= ~IEC958_AES0_CON_NOT_COPYRIGHT;
 	} else if (!strcmp(str, "Permitted")) {
-		iec958.status[1] |= IEC958_AES0_CON_NOT_COPYRIGHT;
+		iec958.status[0] |= IEC958_AES0_CON_NOT_COPYRIGHT;
 	}
 	snd_ctl_elem_value_set_iec958(spdif_output, &iec958);
 	spdif_output_write();
@@ -517,9 +524,9 @@ void consumer_copy_toggled(GtkWidget *togglebutton, gpointer data)
 	if (iec958.status[0] & IEC958_AES0_PROFESSIONAL)
 		return;
 	if (!strcmp(str, "1st")) {
-		iec958.status[0] |= IEC958_AES1_CON_ORIGINAL;
-	} else if (!strcmp(str, "Original")) {
 		iec958.status[1] &= ~IEC958_AES1_CON_ORIGINAL;
+	} else if (!strcmp(str, "Original")) {
+		iec958.status[1] |= IEC958_AES1_CON_ORIGINAL;
 	}
 	snd_ctl_elem_value_set_iec958(spdif_output, &iec958);
 	spdif_output_write();
@@ -539,7 +546,7 @@ void consumer_emphasis_toggled(GtkWidget *togglebutton, gpointer data)
 	if (!strcmp(str, "No")) {
 		iec958.status[0] |= IEC958_AES0_CON_EMPHASIS_NONE;
 	} else if (!strcmp(str, "5015")) {
-		iec958.status[1] |= ~IEC958_AES0_CON_EMPHASIS_5015;
+		iec958.status[0] |= IEC958_AES0_CON_EMPHASIS_5015;
 	}
 	snd_ctl_elem_value_set_iec958(spdif_output, &iec958);
 	spdif_output_write();
@@ -555,15 +562,15 @@ void consumer_category_toggled(GtkWidget *togglebutton, gpointer data)
 		return;
 	if (iec958.status[0] & IEC958_AES0_PROFESSIONAL)
 		return;
-	iec958.status[0] &= ~IEC958_AES1_CON_CATEGORY;
+	iec958.status[1] &= ~IEC958_AES1_CON_CATEGORY;
 	if (!strcmp(str, "DAT")) {
-		iec958.status[0] |= IEC958_AES1_CON_DAT;
+		iec958.status[1] |= IEC958_AES1_CON_DAT;
 	} else if (!strcmp(str, "PCM")) {
-		iec958.status[0] |= IEC958_AES1_CON_PCM_CODER;
+		iec958.status[1] |= IEC958_AES1_CON_PCM_CODER;
 	} else if (!strcmp(str, "CD")) {
-		iec958.status[0] |= IEC958_AES1_CON_IEC908_CD;
+		iec958.status[1] |= IEC958_AES1_CON_IEC908_CD;
 	} else if (!strcmp(str, "General")) {
-		iec958.status[0] |= IEC958_AES1_CON_GENERAL;
+		iec958.status[1] |= IEC958_AES1_CON_GENERAL;
 	}
 	snd_ctl_elem_value_set_iec958(spdif_output, &iec958);
 	spdif_output_write();
@@ -598,7 +605,7 @@ void spdif_output_toggled(GtkWidget *togglebutton, gpointer data)
 			page = 1;
 		}
 		spdif_output_write();
-		gtk_notebook_set_page(GTK_NOTEBOOK(hw_spdif_output_notebook), page);
+		gtk_notebook_set_current_page(GTK_NOTEBOOK(hw_spdif_output_notebook), page);
 		spdif_output_update();
 	}
 }
