@@ -54,9 +54,9 @@ void subst_tilde_in_filename(char * const filename)
 
 	if ((pos_after_tilde = strchr(filename, '~')) != NULL) {
 		pos_after_tilde++;
-		strncpy(new_filename, getenv("HOME"), MAX_FILE_NAME_LENGTH);
-		strncpy(new_filename + strlen(new_filename), pos_after_tilde, MAX_FILE_NAME_LENGTH - strlen(new_filename));
-		new_filename[MAX_FILE_NAME_LENGTH - 1] = '\0';
+		strncpy(new_filename, getenv("HOME"), sizeof(new_filename) - 1);
+		strncpy(new_filename + strlen(new_filename), pos_after_tilde, sizeof(new_filename) - strlen(new_filename) - 1);
+		new_filename[sizeof(new_filename) - 1] = '\0';
 		strncpy(filename, new_filename, MAX_FILE_NAME_LENGTH);
 	}
 }
@@ -78,7 +78,9 @@ int which_cfgfile(char ** const cfgfile)
 			   (inputFile = fopen(SYS_PROFILERC, "r")) == NULL) {
 			res = -ENOENT;
 		} else {
-			fclose(inputFile);
+			if (inputFile != NULL) {
+				fclose(inputFile);
+			}
 			*cfgfile = SYS_PROFILERC;
 			res = EXIT_SUCCESS;
 		}
@@ -94,7 +96,9 @@ int get_file_size(const char * const filename)
 {
 	struct stat file_status;
 
-	strncpy(filename_without_tilde, filename, MAX_FILE_NAME_LENGTH);
+	if (filename_without_tilde != filename) {
+		strncpy(filename_without_tilde, filename, MAX_FILE_NAME_LENGTH);
+	}
 	filename_without_tilde[MAX_FILE_NAME_LENGTH - 1] = '\0';
 	subst_tilde_in_filename(filename_without_tilde);
 	if (stat(filename_without_tilde, &file_status) < 0) {
@@ -470,7 +474,8 @@ int get_pos_name_header_from_card(const char * const buffer, const int profile_n
 	char place_holder;
 	int pos_card_begin, pos_card_end, pos_name_header;
 
-	pos_card_begin = get_card_begin(buffer, profile_number, card_number);
+	if ((pos_card_begin = get_card_begin(buffer, profile_number, card_number)) < 0)
+		return pos_card_begin;
 	pos_card_end = get_card_end(buffer, profile_number, card_number);
 	place_holder = PLACE_HOLDER_STR;
 	strncpy(header, PROFILE_NAME_TEMPL, MAX_SEARCH_FIELD_LENGTH);
@@ -522,7 +527,7 @@ int reorganize_profiles(char * const buffer, const int max_length)
 {
 	int profile_number, card_number, card_number_max;
 	int res;
-	int pos_profile_begin, pos_profile_end, pos_card_begin, pos_card_end, pos_name_header;
+	int pos_profile_begin, pos_card_begin, pos_card_end, pos_name_header;
 	int pos_alsa_section_begin, pos_after_alsa_section;
 	char header[MAX_SEARCH_FIELD_LENGTH];
 	void *buffer_copy = NULL;
@@ -547,7 +552,6 @@ int reorganize_profiles(char * const buffer, const int max_length)
 		compose_search_string(header, PROFILE_HEADER_TEMPL, profile_or_card_number_as_str, place_holder, MAX_SEARCH_FIELD_LENGTH);
 		header[MAX_SEARCH_FIELD_LENGTH - 1] = '\0';
 		snprintf(buffer_copy + strlen(buffer_copy), max_length - strlen(buffer_copy), "%s\n", header);
-		pos_profile_end = get_profile_end(buffer, profile_number);
 		/* search max card number in profile */
 		card_number_max = get_max_card_number_in_profile(buffer, profile_number);
 		for (card_number = 0; card_number <= card_number_max; card_number++)
@@ -641,9 +645,9 @@ int save_restore_alsactl_settings(char * const tmpfile, const int card_number, c
 
 void compose_tmpfile_name(char * const tmpfile, const char * const cfgfile)
 {
-	strncpy(tmpfile, cfgfile, MAX_FILE_NAME_LENGTH);
+	strncpy(tmpfile, cfgfile, MAX_FILE_NAME_LENGTH - 1);
 	tmpfile[MAX_FILE_NAME_LENGTH - 1] = '\0';
-	strncpy(tmpfile + strlen(tmpfile), "_alsactl_tmp", MAX_FILE_NAME_LENGTH - strlen(tmpfile));
+	strncpy(tmpfile + strlen(tmpfile), "_alsactl_tmp", MAX_FILE_NAME_LENGTH - strlen(tmpfile) - 1);
 	tmpfile[MAX_FILE_NAME_LENGTH - 1] = '\0';
 }
 
@@ -1145,13 +1149,16 @@ int save_restore(const char * const operation, const int profile_number, const i
 				fprintf(stderr, "Cannot save settings for card '%d' in profile '%d'.\n", card_number, profile_number);
 				return -errno;
 			}
+			close(res);
 			unlink(cfgfile);
 		} else {
+			close(res);
 			if ((res = open(cfgfile, O_RDWR | 0400000 /* O_NOFOLLOW */, FILE_CREA_MODE)) < 0) {
 				fprintf(stderr, "Cannot open configuration file '%s' for writing.\n", cfgfile);
 				fprintf(stderr, "Cannot save settings for card '%d' in profile '%d'.\n", card_number, profile_number);
 				return -errno;
 			}
+			close(res);
 		}
 		res =  save_profile(profile_number, card_number, profile_name, cfgfile);
 	} else if (!strcmp(operation, ALSACTL_OP_RESTORE)) {
